# Google Search Console - Performance und Indexierung

> **Source:** [Antonio Blago](https://www.youtube.com/channel/UCoIBDdswc5VViHYPTKd0HwA) | **Duration:** 10:41 | **Published:** 20251222
> **URL:** [https://www.youtube.com/watch?v=o5HGyXgGlhA](https://www.youtube.com/watch?v=o5HGyXgGlhA)
> **Views:** 20

In diesem Video stelle ich die Google Search Console vor und gehe Schritt für Schritt durch die verschiedenen Funktionen. Ich zeige die Performance- und Leistungsübersicht, die Indexierung, wichtige Fehlermeldungen und wie man Seiten manuell entfernen lassen kann. Schau dir das Video an, um einen Üb...

---

## Table of Contents

- [Segment 1](#segment-1-00:00-02:00)
- [Segment 2](#segment-2-02:00-04:00)
- [Segment 3](#segment-3-04:00-06:00)
- [Segment 4](#segment-4-06:00-08:00)
- [Segment 5](#segment-5-08:00-10:00)
- [Segment 6](#segment-6-10:00-10:41)

---

### Segment (00:00 - 02:00)

ja hallo also in der Lektion will ich jetzt die Google Search Kole noch mal vorstellen in der Praxis so von dem Layout kannst sich natürlich noch mal ändern dann mir gerne Bescheid geben insofern ist das jetzt eine searchkonsole von einem Kunden die datensensiblen Themen habe ich jetzt natürlich versteckt und so sieht die jetzt quasi in der overview also in der Übersicht aus und dann gehen wir jetzt mal durch die verschiedenen Punkte und dann haben wir hier den wichtigsten Bereich nämlich die Performance und die Leistungsübersicht kann man hier bestimmte Urs noch mal checken hier die Indexierung ist auch sehr wichtig also welche Seiten habt jetzt indexiert wie wo die Sitemap hinterlegt wollt ihr verschiedene Seiten manuell entfernen lassen wie ist quasi die seitenerfahrung also die Nutzererfahrung auch ein sehr wichtiger Punkt die cor webweitals zu berücksichtigen https Verschlüsselung ist eigentlich Standard und falls ihr irgendwie Shopping Produkte hab wenn die auch gelistet accelerated mobile ist noch mal so ein bisschen für für mobile Seitenansicht optimierte Technik und dann hier noch mal so ein paar Details pradcums FAQs Reviews Sitelinks searchbox also PR crums ist so im Prinzip in Blog beispielsweise wenn dann

---

### Segment (02:00 - 04:00)

beispielsweise wenn dann Seitennavigation oben seht Blog Artikel und FQ sagt euch bestimmt das meist gestellte Fragen dann habt ihr auch immer bewertungsnippets und rechts daneben könnt ihr auch immer sitit links darstellen auf eurer Homepage dann könnt ihr auch hier quasi Security und man das ist auch sehr wichtig wenn jetzt ihr gegen Seiten Verstöße habt und dann google euch irgendwie abmaht dann wird es hier angezeigt und ja die weiteren Punkte werden noch mal detaillierter dann eingehen genau also gehen wir jetzt mal Schritt für Schritt und zwar zunächst mal natürlich in die Performance Ansicht also das ist die wichtigste und zwar in den full report genau und jetzt sehen wir hier schon mal die Leistungsübersicht und hier im Blau quasi die klickanzahl dann hier impression also wie viele Seitenaufrufe habt ihr gehabt durchschnittliche clickthr rate also sind so Mikro Conversion Rates und dann hier die average Position also die durchschnittliche Ranking Position auf Google und auf jeden Fall die Verhältnisse in im Gesamt muss man immer berücksichtigen also es hilft nicht nur klickanzahl oder nur impression anzugucken sondern auch immer alle Zahlen in Verhältnis sich anzugucken weil es kann sein dass ihr viel mehr Aufrufe habt als ihr Klicks und dann ist quasi die TTR nicht so gut oder auch rum und das gilt dann

---

### Segment (04:00 - 06:00)

Klicks und dann ist quasi die TTR nicht so gut oder auch rum und das gilt dann immer für die einzelnen Seiten auch zu könnt ihr auch beispielsweise die average CTA CTR an zeigen lassen und die im durchschnittlichen Bereich bei 2% das schon mal gut und auch die average Position und man sieht hier z.B dass die average Position natürlich besser geworden ist mit der Zeit es kann sein halt wenn ihr z.B sehr viele neue aufrufe habt und eure Impressionen ganz stark ansteigen dass eure average Position erstmal sinkt weil ihr für mehr Keyword rank das ist am Anfang ganz oft so dass wenn ihr erer für sehr wenige Keywords ranked also für 10 20 Keywords dann ist es noch nicht wirklich relevant und dann wenn ihr mal für 100 500 oder ta000 Keywords rankt dann wird sich das irgendwann zwischen 20 und 30 so einpendeln im Durchschnitt wahrscheinlich und ähm genau das immer auch wichtig zu berücksichtigen genau und was ihr auch immer machen solltet ist auf jeden Fall hier natürlich verschiedene Abstände zu analysieren aber das werden wir noch mal ähm später in einer anderen Folge noch mal genauer durchgehen genau erstmal die anderen Bereiche genau page Indexierung ist ein sehr wichtiger Bereich und der sollte oft überprüft werden dass alle relevanten Seiten natürlich indexiert sind und alle nicht relevanten sollten nicht indexiert sein weil sonst kann es sein dass ihr Google mit zu ir relelevanten Seiten vollspamt und das könnt auch euer Ranking beeinflussen genau das könnt ihr hier auch dann genau

---

### Segment (06:00 - 08:00)

beeinflussen genau das könnt ihr hier auch dann genau analysieren also es gibt den Fehler page oder den nicht den Fehler den den Grund warum die Seiten nicht indexiert sind oder zum grauen Index gehören ist page Redirect also eine Umleitung das ist auch valider Fall dann ein alter native Seite mit dem richtigen kanonischen Tag Fall auf jeden Fall also wenn ihr eine Seite mit einem kanonischen TEAG kennzeichnet dann sagt ihr damit eigentlich dass Google diese Seite schon mal indexiert habt aber dass sie ähnlich ist zu der Seite die ihr als kanonisch bezeichnet habt und dann kann es auch den Fehler geben dass Google sagt nein an der andere Seite ist ähnlicher als die angezeigt habt als kanonisch und dann würde das hier auch angezeigt werden und genau und das ist z.B hier der Fehler duplicate Google choose different Canonical Tag den User also Google bezeichnet hier eine andere Seite als kanonisch als die der User ja gekennzeichnet hat und da muss man halt noch mal reingehen und sich anschauen warum das passiert ist genau und dann wichtig ist auf jeden Fall hier not found das sollte man auf jeden Fall öfters überprüfen ob Google da alles richtig macht natürlich kann man da nicht immer alles richtig machen weil Google auch hfig mal nicht richtige 404 anzeigt genau und dann gibt's auch noch dann gibt's z.B auch den Fehler duplicate und das sollte man auf jeden Fall auch berücksichtigen also wenn

---

### Segment (08:00 - 10:00)

duplicate und das sollte man auf jeden Fall auch berücksichtigen also wenn Google eine duplikatseite gefunden hat dann excluded by no Index Tag also quasi hab Seiten als nicht indexierbar bezeichnet das ist auch immer wel wichtig dann Block bei robots txt das ist genau was wir auch schon gesprochen haben dieser robots txt Datei die Seiten habt ihr blockiert da sollt ihr natürlich immer gucken ob das die richtigen Seiten sind und dann sieht man hier auch noch mal andere Fehler bei vier issues und crawed currently not Index also die Seite hat Google gefunden aber es sie ist nicht indexiert diese sollte sollte man auch öfters natürlich überprüfen und dann genau schon erwähnt duplicate duplicate Google onical User also dass die kanonische Seite et was eine andere Seite ist genau und da gibt's noch natürlich 403 Fehler also der der Inhalt ist blockiert also der sollte natürlich nicht die Inhalte Google öffentlich zugänglich machen also z.B Mitgliederbereiche und solche Fehler sind das genau jetzt sind wir in dem Sitemap Bereich und das haben wir auch schon mal besprochen dass die Sitemap sehr wichtig ist für Google und zu sehen welche Seiten ähm indexiert werden sollen m und hier könnt ihr quasi eure Sitemap einreichen da gibt ihr einfach dem fah ein von der Sitemap oder dem Index der Sitemap und dann sieht ihr wie viele Seiten dort gelesen worden sind und ob es erfolgreich äh gelesen worden ist eure Sitemap genau in dem Bereich Removals da könnt

---

### Segment (10:00 - 10:41)

äh gelesen worden ist eure Sitemap genau in dem Bereich Removals da könnt ihr eure Seiten manuell entfernen lassen also wenn ihr z.B Seiten 404 oder so als 404 Fehler entdeckt worden sind durch Google und die wollte durch Google gar nicht mehr auffindbar machen dann könnt ihr natürlich auch hier bitte berücksichtige die Seiten nicht dann könnt ihr diese hier auch manuell einreichen genau und in den nächsten Lektionen werden wir jetzt noch mal die anderen Bereiche äh durchgehen und genau bis gleich

---


*Transcript source: youtube_auto_generated*
*Confidence: 80%*